summaryrefslogtreecommitdiffstats
path: root/lib/kofficeui/KoGuideLineDia.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kofficeui/KoGuideLineDia.h')
-rw-r--r--lib/kofficeui/KoGuideLineDia.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/kofficeui/KoGuideLineDia.h b/lib/kofficeui/KoGuideLineDia.h
index 7dc9e0f8..0f2fcecf 100644
--- a/lib/kofficeui/KoGuideLineDia.h
+++ b/lib/kofficeui/KoGuideLineDia.h
@@ -42,14 +42,14 @@ public:
/**
* @brief Constructor
*
* @param tqparent The tqparent widget
* @param pos the actual position of the guide line
* @param minPos the minimal position of the guide line
* @param maxPos the maximal position of the guide line
* @param unit The unit used in the document
* @param name The name is send to the TQObject constructor
*/
- KoGuideLineDia( TQWidget *tqparent, double pos, double minPos, double maxPos,
+ KoGuideLineDia( TQWidget *parent, double pos, double minPos, double maxPos,
KoUnit::Unit unit, const char *name = 0L );
/**
@@ -59,13 +59,13 @@ public:
* and the orientation of the guide line is changed the value will be set to pos.x()
* or pos.y() according to the orientation.
*
* @param tqparent the tqparent widget
* @param pos the actual position of cursor
* @param rect the rect in where the guide can be placed
* @param unit the unit used in the document
* @param name the name is send to the TQObject constructor
*/
- KoGuideLineDia( TQWidget *tqparent, KoPoint &pos, KoRect &rect,
+ KoGuideLineDia( TQWidget *parent, KoPoint &pos, KoRect &rect,
KoUnit::Unit unit, const char *name = 0L );
/**
* @brief the position
@@ -42,14 +42,14 @@ public:
* @brief Constructor
*
- * @param tqparent The tqparent widget
+ * @param parent The parent widget
* @param pos the actual position of the guide line
* @param minPos the minimal position of the guide line
@@ -59,13 +59,13 @@ public:
* or pos.y() according to the orientation.
*
- * @param tqparent the tqparent widget
+ * @param parent the parent widget
* @param pos the actual position of cursor
* @param rect the rect in where the guide can be placed